==> haskell-adjunctions-4.4-90-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-GzaEADroQTbIa8Cmxr2sGo
key: adjunctions-4.4-GzaEADroQTbIa8Cmxr2sGo
license: BSD-3-Clause
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
abi: 5201b6c804f85081758f5f2008a789b2
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
import-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-GzaEADroQTbIa8Cmxr2sGo
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-GxLjkJReVVVCdZ5ZrqdrbQ
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    distributive-0.6-46i0ICRb7I89PMCNGFAS12
    free-5.1.1-IFTu7VxDjJvBDG90IM4DH mtl-2.2.2
    profunctors-5.4-8SgccOoggxTAmI1JMELV50
    semigroupoids-5.3.2-4AsvIVMQIH9DuCVwKKp02j
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4-92-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-JV10ih7Aq78D3YDhA1xSZv
key: adjunctions-4.4-JV10ih7Aq78D3YDhA1xSZv
license: BSD-3-Clause
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
abi: 17f5a09dbf861ef2af4c308be246316c
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
import-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-JV10ih7Aq78D3YDhA1xSZv
depends:
    array-0.5.3.0 base-4.12.0.0 comonad-5.0.5-GxLjkJReVVVCdZ5ZrqdrbQ
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    distributive-0.6-46i0ICRb7I89PMCNGFAS12
    free-5.1.1-Ij3ZXSHiEBQ7mGblegjtYc mtl-2.2.2
    profunctors-5.4-Dq7lbhRyDqlE72xPOLahfX
    semigroupoids-5.3.2-K5SaVm4N6AL6wYPHZFU5px
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
